pub enum Ingredient {
Empty,
Item(ItemRef),
Tag(Identifier),
Choice(&'static [ItemRef]),
}Expand description
Represents what items can satisfy a recipe slot.
Matches Java’s Ingredient class.
Variants
Empty
Matches nothing (empty slot required).
Item(ItemRef)
Matches a single specific item.
Tag(Identifier)
Matches any item in a tag.
Choice(&'static [ItemRef])
Matches any of the listed items (OR).
Implementations
Sourceimpl Ingredient
impl Ingredient
Sourcepub fn test(&self, stack: &ItemStack) -> bool
pub fn test(&self, stack: &ItemStack) -> bool
Tests if the given item stack satisfies this ingredient.
Sourcepub fn get_items(&self) -> Vec<ItemRef> ⓘ
pub fn get_items(&self) -> Vec<ItemRef> ⓘ
Returns all items that could satisfy this ingredient (for recipe book display).
Sourcepub fn eq_ingredient(&self, other: &Self) -> bool
pub fn eq_ingredient(&self, other: &Self) -> bool
Compares two ingredients for equality (used for symmetry detection).